==> oto-service-api-0.2.28-20241209.022239-2-sources.jar: cn/com/duiba/oto/dto/oto/goods/order/OrderDto.java <==
package cn.com.duiba.oto.dto.oto.goods.order;

import lombok.Data;

import java.io.Serializable;
import java.util.Date;

/**
 * @Description
 * @Author huliangsheng
 * @Date 2024/8/14 15:46
 */
@Data
public class OrderDto implements Serializable {

    private static final long serialVersionUID = 1220085817764510885L;

    /**
     * 主键
     */
    private Long id;

    /**
     * 订单编号
     */
    private String orderNo;

    /**
     * 下单商品数量
     */
    private Integer orderStocks;

    /**
     * 实际扣减库存数量
     */
    private Integer actualStocks;

    /**
     * 订单状态：0:待支付 1:已支付 2:已完成 3:已退款
     */
    private Integer orderStatus;

    /**
     * 支付订单编号
     */
    private String paymentNo;

    /**
     * tb_oto_wx_user.id 微信账户id
     */
    private Long userId;

    /**
     * 客户id
     */
    private Long custId;

    /**
     * 商品id
     */
    private Long goodsId;

    /**
     * 购买的商品规格
     */
    private String goodsStandard;

    /**
     * 购买数量
     */
    private Integer purchaseCount;

    /**
     * 原价
     */
    private Integer originalPrice;

    /**
     * 实付价格
     */
    private Integer paymentPrice;

    /**
     * 立减金
     */
    private Integer minusPrice;

    /**
     * 核销时间
     */
    private Date verifyTime;

    /**
     * 扩展信息
     */
    private String extraJson;

    /**
     * 创建时间
     */
    private Date gmtCreate;

    /**
     * 更新时间
     */
    private Date gmtModified;

    /**
     * 预约领取时间
     */
    private Date appointmentTime;

    /**
     * 领取方式
     * 1：客户自提 2：销售待领
     *
     * @see cn.com.duiba.oto.enums.goods.order.OrderReceiveTypeEnum
     */
    private Integer receiveType;


}

==> oto-service-api-0.2.32-20241220.095455-10-sources.jar: cn/com/duiba/oto/dto/oto/goods/order/OrderDto.java <==
package cn.com.duiba.oto.dto.oto.goods.order;

import lombok.Data;

import java.io.Serializable;
import java.util.Date;

/**
 * @Description
 * @Author huliangsheng
 * @Date 2024/8/14 15:46
 */
@Data
public class OrderDto implements Serializable {

    private static final long serialVersionUID = 1220085817764510885L;

    /**
     * 主键
     */
    private Long id;

    /**
     * 订单编号
     */
    private String orderNo;

    /**
     * 下单商品数量
     */
    private Integer orderStocks;

    /**
     * 实际扣减库存数量
     */
    private Integer actualStocks;

    /**
     * 订单状态：0:待支付 1:已支付 2:已完成 3:已退款
     */
    private Integer orderStatus;

    /**
     * 支付订单编号
     */
    private String paymentNo;

    /**
     * tb_oto_wx_user.id 微信账户id
     */
    private Long userId;

    /**
     * 客户id
     */
    private Long custId;

    /**
     * 商品id
     */
    private Long goodsId;

    /**
     * 购买的商品规格
     */
    private String goodsStandard;

    /**
     * 购买数量
     */
    private Integer purchaseCount;

    /**
     * 原价
     */
    private Integer originalPrice;

    /**
     * 实付价格
     */
    private Integer paymentPrice;

    /**
     * 立减金
     */
    private Integer minusPrice;

    /**
     * 核销时间
     */
    private Date verifyTime;

    /**
     * 扩展信息
     */
    private String extraJson;

    /**
     * 创建时间
     */
    private Date gmtCreate;

    /**
     * 更新时间
     */
    private Date gmtModified;

    /**
     * 预约领取时间
     */
    private Date appointmentTime;

    /**
     * 领取方式
     * 1：客户自提 2：销售待领
     *
     * @see cn.com.duiba.oto.enums.goods.order.OrderReceiveTypeEnum
     */
    private Integer receiveType;

    /**
     * 订单来源
     *
     * @see cn.com.duiba.oto.enums.goods.order.OrderSourceEnum
     * 1：客户自己下单 2：管理后台手动录入
     */
    private Integer orderSource;

}
